@@ -1,22 +1,5 @@
-# packaging steps and troubleshooting ####
-# install.packages('devtools'); library(devtools); 
-# install.packages('roxygen2'); library(roxygen2); 
-# install.packages('testthat'); library(testthat)
-# devtools::install_github("rstudio/packrat")
-# Tools|Project Options|Packrat|Use Packrat with this project
-# Tools|Project Options|Build Tools|Configure
-# Replace DESCRIPTION file; Delete "Read and delete me" file
-# devtools::document()
-# roxygen2::roxygenize('QFRM')
-# .libPaths(c("z:/", .libPaths()))
-# system("R CMD INSTALL QFRM")
-# Uninstal "inconsolata" MiKTeX package (in Package Manager)
-# run "R CMD Rd2pdf --pdf QFRM" in z:
-# options: --as-cran --no-manual --no-vignettes --no-clean, support.rstudio.com/hc/en-us/articles/200486518
-# run `updmap` on Win command line to fix inconsoladate MikTeX package issue with "Font ts1-zi4r at 540 not found"
-
 ## Opt #####
-#' \code{Opt} object constructor
+#' @title \code{Opt} object constructor
 #' @description An S3 object constructor for an option contract (financial derivative)
 #' @author Oleg Melnikov, Department of Statistics, Rice University, Spring 2015
 #' 
@@ -33,15 +16,16 @@
 #' @return A list of class \code{Opt}
 #' @examples
 #' Opt()  #Creates an S3 object for an option contract  
-#' Opt(Right='Put')   #See J.C.Hull, OFOD'2014, 9-ed, Fig.13.10, p.289
+#' Opt(Right='Put')   #See J. C. Hull, OFOD'2014, 9-ed, Fig.13.10, p.289
 #' @export
 #' 
-Opt = function(Style=c('European','American','Asian','Binary','AverageStrike','Barrier',
-                       'Chooser','Compound','DeferredPayment','ForeignEquity','ForwardStart','Gap','HolderExtendible',
-                       'Ladder','Lookback','MOPM','Perpetual','Quotient','Rainbow','Shout','SimpleChooser','VarianceSwap'), 
-               Right=c('Call','Put','Other'), S0=50, ttm=2, K=52, 
-               Curr='$', ContrSize=100, SName='A stock share', SSymbol='') { 
-
+Opt = function(
+  Style=c('European','American','Asian','Binary','AverageStrike','Barrier',
+          'Chooser','Compound','DeferredPayment','ForeignEquity','ForwardStart','Gap','HolderExtendible',
+          'Ladder','Lookback','MOPM','Perpetual','Quotient','Rainbow','Shout','SimpleChooser','VarianceSwap'), 
+  Right=c('Call','Put','Other'), S0=50, ttm=2, K=52, 
+  Curr='$', ContrSize=100, SName='A stock share', SSymbol='') { 
+  
 
   Style = match.arg(Style)
   s=list(Name=Style)
@@ -55,7 +39,7 @@ Opt = function(Style=c('European','American','Asian','Binary','AverageStrike','B
   s$Barrier = (Style == 'Barrier')
   s$Chooser = (Style == 'Chooser')
   s$Compound = (Style == 'Compound')
-  s$DP = (Style == 'DeferredPayment')
+  s$DeferredPayment = (Style == 'DeferredPayment')
   s$ForeignEquity = (Style == 'ForeignEquity')
   s$ForwardStart = (Style == 'ForwardStart')
   s$Gap = (Style == 'Gap')
@@ -84,7 +68,7 @@ Opt = function(Style=c('European','American','Asian','Binary','AverageStrike','B
 }
 
 ## OptPx #####
-#' \code{OptPx} object constructor
+#' @title \code{OptPx} object constructor
 #' @description An S3 object constructor for lattice-pricing specifications for an option contract. \code{Opt} object is inhereted.
 #' @author Oleg Melnikov, Department of Statistics, Rice University, Spring 2015
 #' 
@@ -93,7 +77,7 @@ Opt = function(Style=c('European','American','Asian','Binary','AverageStrike','B
 #' @param q   A dividend yield (as annualized rate), Hull/p291
 #' @param rf  A foreign risk free rate (annualized), Hull/p.292
 #' @param vol A volaility (as Sd.Dev, sigma)
-#' @param n   A number of time steps in BOPM calculation
+#' @param NSteps   A number of time steps in BOPM calculation
 #' 
 #' @return A list of class \code{OptPx} with parameters supplied to \code{Opt} and \code{OptPx} constructors
 #' @examples
@@ -105,17 +89,17 @@ Opt = function(Style=c('European','American','Asian','Binary','AverageStrike','B
 #' o = OptPx(Opt(Right='Call', S0=42, ttm=.5, K=40), r=.1, vol=.2)  
 #' @export
 #' 
-OptPx = function(o=Opt(), r=0.05, q=0, rf=0, vol=.30, n=2) { 
+OptPx = function(o=Opt(), r=0.05, q=0, rf=0, vol=.30, NSteps=3) { 
   stopifnot(is.Opt(o), is.numeric(r), r>0, r<1, is.numeric(vol), is.numeric(q), is.numeric(rf))
   
-  dt=o$ttm/n           # time interval between consequtive two time steps
+  dt=o$ttm/NSteps           # time interval between consequtive two time steps
   u=exp(vol*sqrt(dt))  # stock price up move factor 
   d=1/u                # stock price down move factor
   SYld = r-q-rf        # yield of the underlying asset, p.458
   a = exp(SYld * dt)   # growth factor, p.452
 
   o$r = r;   o$q = q;   o$rf = rf;   o$vol = vol
-  o$n = n;   o$u = u;   o$d = d;   o$dt = dt;   o$a = a
+  o$NSteps = NSteps;   o$u = u;   o$d = d;   o$dt = dt;   o$a = a
   o$p = p=(a-d)/(u-d) # probability of up move over one time interval dt
   o$SYld = SYld
 #   o$BS = BS
@@ -127,7 +111,7 @@ OptPx = function(o=Opt(), r=0.05, q=0, rf=0, vol=.30, n=2) {
 }
 
 ## OptPos #####
-#' \code{OptPos} object constructor
+#' @title \code{OptPos} object constructor
 #' @description S3 object constructor for lattice-pricing specs of an option contract. Inherits \code{Opt} object.
 #' @author Oleg Melnikov, Department of Statistics, Rice University, Spring 2015
 #' 
@@ -159,7 +143,7 @@ OptPos = function(o=Opt(), Pos=c('Long', 'Short'), Prem=0){
 }
 
 ## is.* #####
-#' Is an object \code{Opt}?
+#' @title Is an object \code{Opt}?
 #' @description Tests the argument for the specific class type.
 #' @author Oleg Melnikov
 #' @param o     Any object
@@ -169,9 +153,9 @@ OptPos = function(o=Opt(), Pos=c('Long', 'Short'), Prem=0){
 #' is.Opt(1:3)    #verifies that code{1:3} is not an object of class \code{Opt}
 #' @export
 #' 
-is.Opt = function(o) is(o,'Opt')
+is.Opt = function(o) methods::is(o,'Opt')
 
-#' Is an object \code{OptPx}?
+#' @title Is an object \code{OptPx}?
 #' @description Tests the argument for the specific class type.
 #' @author Oleg Melnikov
 #' @param o     Any object
@@ -180,9 +164,9 @@ is.Opt = function(o) is(o,'Opt')
 #' is.OptPx(OptPx(Opt(S0=20), r=0.12))
 #' @export
 #' 
-is.OptPx = function(o) is(o,'OptPx')
+is.OptPx = function(o) methods::is(o,'OptPx')
 
-#' Is an object \code{OptPos}?
+#' @title Is an object \code{OptPos}?
 #' @description Tests the argument for the specific class type.
 #' @author Oleg Melnikov
 #' @param o     Any object
@@ -191,9 +175,9 @@ is.OptPx = function(o) is(o,'OptPx')
 #' is.OptPos(OptPos())
 #' @export
 #' 
-is.OptPos = function(o) is(o, 'OptPos')
+is.OptPos = function(o) methods::is(o, 'OptPos')
 
-#' Coerce an argument to \code{OptPos} class.
+#' @title Coerce an argument to \code{OptPos} class.
 #' @author Oleg Melnikov
 #' @param o    A \code{Opt} or \code{OptPx} object
 #' @param Pos Specify position direction in your portfolio. \code{Long} indicates that you own security (it's an asset). \code{Short} that you shorted (short sold) security (it's a liability).
@@ -210,7 +194,7 @@ as.OptPos = function(o=Opt(), Pos=c('Long', 'Short'), Prem=0){
 }
 
 ## BOPM_Eu #####
-#' European option valuation (vectorized computation).
+#' @title European option valuation (vectorized computation).
 #' @description A helper function to price European options via a vectorized (fast, memory efficient) approach.
 #' @author Oleg Melnikov, Department of Statistics, Rice University, Spring 2015
 #' Code adopted Gilli & Schumann's R implementation to \code{Opt*} objects
@@ -222,10 +206,10 @@ as.OptPos = function(o=Opt(), Pos=c('Long', 'Short'), Prem=0){
 #' @examples 
 #' #Fig.13.11, Hull/9e/p291:
 #' o = Opt(Style='European', Right='Call', S0=810, ttm=.5, K=800)
-#' (o <- BOPM_Eu( OptPx(o, r=.05, q=.02, vol=.2, n=2)))$PxBT
+#' (o <- BOPM_Eu( OptPx(o, r=.05, q=.02, vol=.2, NSteps=2)))$PxBT
 #' 
 #' o = Opt('Eu', 'C', 0.61, .5, 0.6, SName='USD/AUD')
-#' o = OptPx(o, r=.05, q=.02, vol=.12, n=2)
+#' o = OptPx(o, r=.05, q=.02, vol=.12, NSteps=2)
 #' (o <- BOPM_Eu(o))$PxBT
 #' @export
 #' 
@@ -233,28 +217,29 @@ BOPM_Eu = function(o=OptPx()){
   stopifnot(is.OptPx(o), o$Style$European) # this function needs OptPx object and European option
   
   with(o, {
-    S = S0*d^(n:0)*u^(0:n)            # vector of terminal stock prices, lowest to highest (@t=ttm)
+    S = S0*d^(NSteps:0)*u^(0:NSteps)            # vector of terminal stock prices, lowest to highest (@t=ttm)
     O = pmax(o$Right$SignCP*(S - K), 0)          # vector of terminal option payouts (@t=ttm)
-    csl = cumsum(log(c(1,1:n)))       #-- logs avoid overflow & truncation
-    tmp = csl[n+1] - csl - csl[(n+1):1] + log(p)*(0:n) + log(1-p)*(n:0)
+    csl = cumsum(log(c(1,1:NSteps)))       #-- logs avoid overflow & truncation
+    tmp = csl[NSteps+1] - csl - csl[(NSteps+1):1] + log(p)*(0:NSteps) + log(1-p)*(NSteps:0)
     o$PxBT = DF_ttm * sum(exp(tmp)*O)
     return(o) #-- spot option price (at time 0)
   })
 }
 
 # BS #####
-#' Black-Scholes (BS) pricing model 
+#' @title Black-Scholes (BS) pricing model 
 #' @description a wrapper function for BS_Simple; uses \code{OptPx} object as input.
 #' @author Oleg Melnikov, Department of Statistics, Rice University, Spring 2015
 #' @param o   An \code{OptPx} object
 #' @return An original \code{OptPx} object with \code{BS} list as components of Black-Scholes formular. 
 #'   See \code{BS_Simple}.
 #' @references Hull, J.C., \emph{Options, Futures and Other Derivatives}, 9ed, 2014. Prentice Hall. 
-#' ISBN 978-0-13-345631-8, \url{http://www-2.rotman.utoronto.ca/~hull/ofod/index.html}.
+#' ISBN 978-0-13-345631-8, \url{http://www-2.rotman.utoronto.ca/~hull/ofod}. \url{http://amzn.com/0133456315}
+#' 
 #' @examples 
 #' #See Hull, p.338, Ex.15.6. #Create an option and price it
 #' o = Opt(Style='Eu', Right='Call', S0 = 42, ttm = .5, K = 40) 
-#' o = BS( OptPx(o, r=.1, vol=.2, n=NA)) 
+#' o = BS( OptPx(o, r=.1, vol=.2, NSteps=NA)) 
 #' o$PxBS #print call option price computed by Black-Scholes pricing model
 #' o$BS$Px$Put #print put option price computed by Black-Scholes pricing model
 #' 
@@ -269,7 +254,7 @@ BS = function(o=OptPx()){ #o=OptPx()
 }
 
 # BS_Simple input ####
-#' Black-Scholes formula
+#' @title Black-Scholes formula
 #' @description Black-Scholes (aka Black-Scholes-Merton, BS, BSM) formula for simple parameters
 #' @author Robert Abramov, Department of Statistics, Rice University, Spring 2015
 #'
@@ -289,7 +274,7 @@ BS = function(o=OptPx()){ #o=OptPx()
 #' \code{Nd2} for \eqn{N(d_2)}, N\code{CallPxBS} for BSM call price, \code{PutPxBS} for BSM put price
 #' 
 #' @references Hull, J.C., \emph{Options, Futures and Other Derivatives}, 9ed, 2014. Prentice Hall. 
-#' ISBN 978-0-13-345631-8, \url{http://www-2.rotman.utoronto.ca/~hull/ofod/index.html}.
+#' ISBN 978-0-13-345631-8, \url{http://www-2.rotman.utoronto.ca/~hull/ofod}. \url{http://amzn.com/0133456315}
 #' \url{http://www.theresearchkitchen.com/archives/106}
 #'
 #' @examples
@@ -313,18 +298,18 @@ BS_Simple <- function(S0=42, K=40, r=.1, q=0, ttm=.5, vol=.2) {
   
   d1 = (log(S0/K)+(r-q+(vol^2)/2)*ttm)/(vol*sqrt(ttm))
   d2 = d1 - vol * sqrt(ttm)
-  Nd1 = pnorm(d1)
-  Nd2 = pnorm(d2) #probability that a call option is exercised in a risk-neutral world, see Hull, p.337
+  Nd1 = stats::pnorm(d1)
+  Nd2 = stats::pnorm(d2) #probability that a call option is exercised in a risk-neutral world, see Hull, p.337
   
   Call = S0*exp(-q*ttm)*Nd1 - K*exp(-r*ttm)*Nd2  # See Hull, p.335, (15.20); p.373, (17.4)
-  Put = K*exp(-r*ttm) * pnorm(-d2) - S0*exp(-q*ttm)*pnorm(-d1) # See Hull, p.335, (15.21); p.373.(17.5)
+  Put = K*exp(-r*ttm) * stats::pnorm(-d2) - S0*exp(-q*ttm)*stats::pnorm(-d1) # See Hull, p.335, (15.21); p.373.(17.5)
   Px = list(Call = Call, Put = Put) 
   BS = list(d1=d1, d2=d2, Nd1=Nd1, Nd2=Nd2, Px=Px)
   return(BS)
 }
 
 # BOPM #####
-#' Binomial option pricing model
+#' @title Binomial option pricing model
 #' @description Compute option price via binomial option pricing model (recombining symmetric binomial tree). 
 #'  If no tree requested for European option, vectorized algorithm is used. 
 #' @author Oleg Melnikov, Department of Statistics, Rice University, Spring 2015
@@ -333,37 +318,39 @@ BS_Simple <- function(S0=42, K=40, r=.1, q=0, ttm=.5, vol=.2) {
 #' @seealso \code{\link{BOPM_Eu}} for European option via vectorized approach.
 #' @return An original \code{OptPx} object with \code{PxBT} field as the binomial-tree-based price of an option 
 #' and (an optional) the fullly-generated binomial tree in \code{BT} field.
-#'  \code{IncBT = FALSE}: option price value (type \code{double}, class \code{numeric})
-#'  \code{IncBT = TRUE}: binomial tree as a list (of length (\code{o$n+1}) of numeric matrices (2 x \code{i}). 
+#'  \itemize{
+#'  \item{ \code{IncBT = FALSE}: option price value (type \code{double}, class \code{numeric})}
+#'  \item{\code{IncBT = TRUE}: binomial tree as a list 
+#'    (of length (\code{o$NSteps+1}) of numeric matrices (2 x \code{i})}}
 #'    Each matrix is a set of possible i outcomes at time step i 
 #'    columns: (underlying prices, option prices)
 #' @references Hull, J.C., \emph{Options, Futures and Other Derivatives}, 9ed, 2014. Prentice Hall. 
-#' ISBN 978-0-13-345631-8, \url{http://www-2.rotman.utoronto.ca/~hull/ofod/index.html}.
-#' @examples 
+#' ISBN 978-0-13-345631-8, \url{http://www-2.rotman.utoronto.ca/~hull/ofod}. \url{http://amzn.com/0133456315}
+#' 
 #' #See Fig.13.11, Hull/9e/p291. #Create an option and price it
 #' o = Opt(Style='Eu', Right='C', S0 = 808, ttm = .5, K = 800) 
-#' o = BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, n=2), IncBT=TRUE) 
+#' o = BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, NSteps=2), IncBT=TRUE) 
 #' o$PxBT #print added calculated price to PxBT field
 #' 
 #' #Fig.13.11, Hull/9e/p291:
 #' o = Opt(Style='Eu', Right='C', S0=810, ttm=.5, K=800)
-#' BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, n=2), IncBT=TRUE)$PxBT 
+#' BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, NSteps=2), IncBT=TRUE)$PxBT 
 #' 
 #' #DerivaGem diplays up to 10 steps:
 #' o = Opt(Style='Am', Right='C', 810, .5, 800)
-#' BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, n=20), IncBT=TRUE)      
+#' BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, NSteps=20), IncBT=TRUE)      
 #' 
 #' #DerivaGem computes up to 500 steps:
 #' o = Opt(Style='American', Right='Put', 810, 0.5, 800)
-#' BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, n=1000), IncBT=FALSE)   
+#' BOPM( OptPx(o, r=0.05, q=0.02, vol=0.2, NSteps=1000), IncBT=FALSE)   
 #' @export
 #' 
 BOPM = function(o=OptPx(), IncBT=TRUE){ #o=OptPx()
   stopifnot(is.OptPx(o), o$Style$Vanilla); # algorithm requires that a OptPx object is provided
-  n=o$n; p=o$p; K=o$K
+  NSteps=o$NSteps; p=o$p; K=o$K
   
   if (o$Style$European && !IncBT) return(BOPM_Eu(o)) else { 
-    S = with(o, S0*d^(0:n)*u^(n:0)) # vector of terminal stock prices, lowest to highest (@t=ttm)
+    S = with(o, S0*d^(0:NSteps)*u^(NSteps:0)) # vector of terminal stock prices, lowest to highest (@t=ttm)
     O = pmax(o$Right$SignCP * (S - K), 0) # vector of terminal option payouts (@t=ttm)
     #-- American option pricing
     #-- a vector stores stock prices at any time point
@@ -376,7 +363,7 @@ BOPM = function(o=OptPx(), IncBT=TRUE){ #o=OptPx()
       return(cbind(S, O))
     }
     
-    BT = append(list(cbind(S, O)), sapply(n:1, RecalcOSonPriorTimeStep)) #binomial tree
+    BT = append(list(cbind(S, O)), sapply(NSteps:1, RecalcOSonPriorTimeStep)) #binomial tree
     o$PxBT = BT[[length(BT)]][[2]]  # add BOPM price
     if (IncBT) o$BT = BT
     return(o)
@@ -384,7 +371,7 @@ BOPM = function(o=OptPx(), IncBT=TRUE){ #o=OptPx()
 }
 
 # Profit #####
-#' Computes payout/profit values
+#' @title Computes payout/profit values
 #' @description Computes payout/profit values
 #' @author Oleg Melnikov, Department of Statistics, Rice University, Spring 2015
 #' @param o   An object of class \code{Opt*}
@@ -392,7 +379,7 @@ BOPM = function(o=OptPx(), IncBT=TRUE){ #o=OptPx()
 #' @return A numeric matrix of size \code{[length(S), 2]}. Columns: stock prices, corresponding option profits
 #' @examples 
 #' Profit(o=Opt())
-#' plot( print( Profit(OptPos(Prem=2.5), S=40:60)), type='l'); grid()
+#' graphics::plot( print( Profit(OptPos(Prem=2.5), S=40:60)), type='l'); grid()
 #' @export
 #' 
 Profit = function(o=OptPos(), S=o$S0){
@@ -403,6 +390,80 @@ Profit = function(o=OptPos(), S=o$S0){
 } 
 
 
+#' @title Bivariate Standard Normal CDF
+#' @description Bivariate Standard Normal CDF Calculator For Given Values of x, y, and rho
+#' @author Robert Abramov, Department of Statistics, Rice University, 2015
+#' @details This runs a bivariate standard normal pdf then calculates the cdf from that based on the input parameters
+#' 
+#' @param x The \eqn{x} value (want probability under this value of \eqn{x}); values in \eqn{(-25, 25)}
+#' @param y The \eqn{y} value (want probability under this value of \eqn{y}); values in \eqn{(-25, 25)}
+#' @param rho The correlation between variables \eqn{x} and \eqn{y}; values in \eqn{[-1, 1]}
+#' 
+#' @return Density under the bivariate standard normal distribution 
+#' 
+#' @references Adapted from
+#' "Bivariate normal distribution with R", Edouard Tallent's blog from Sep 21, 2012
+#' \cr https://quantcorner.wordpress.com/2012/09/21/bivariate-normal-distribution-with-r
+#'
+#' @examples
+#' pbnorm(1, 1, .5)
+#' #pbnorm(2, 2, 0)
+#' #pbnorm(-1, -1, .35)
+#' #pbnorm(0, 0, 0)
+#' 
+#' ttl = 'cdf of x, at y=0'
+#' X = seq(-5,5,1)
+#' graphics::plot(X, sapply(X, function(x) pbnorm(0,x,0)), type='l', main=ttl)
+#' 
+#' @export
+pbnorm <- function(x=0, y=0, rho=0){
+  stopifnot(is.numeric(x), is.numeric(y), is.numeric(rho), 
+            rho <= 1, rho >= -1, x < 25, x > -25, y < 25, y > -25)
+  
+  mu1 <- 0  # expected value of x
+  mu2 <- 0  # expected value of y
+  sig1 <- 1  # variance of x
+  sig2 <- 1  # variance of y
+  if(rho == 1){
+    rho = 0.9999999
+  } else if(rho == -1){
+    rho = -0.9999999
+  }
+  
+  
+  # Some additional variables for x-axis and y-axis 
+  xm <- -25
+  xp <- 25
+  ym <- -25
+  yp <- 25
+  
+  xx <- seq(xm, xp, length= as.integer((xp + abs(xm)) * 10))  # vector series x
+  yy <- seq(ym, yp, length= as.integer((yp + abs(ym)) * 10))  # vector series y
+  
+  # Core function
+  bivariate <- function(xx,yy){
+    term1 <- 1 / (2 * pi * sig1 * sig2 * sqrt(1 - rho^2))
+    term2 <- (xx - mu1)^2 / sig1^2
+    term3 <- -(2 * rho * (xx - mu1)*(yy - mu2))/(sig1 * sig2)
+    term4 <- (yy - mu2)^2 / sig2^2
+    z <- term2 + term3 + term4
+    term5 <- term1 * exp((-z / (2 *(1 - rho^2))))
+    return (term5)
+  }
+  
+  # Computes the density values
+  z <- outer(xx,yy,bivariate)
+  
+  x.value <- which.min(abs(xx-x))
+  y.value <- which.min(abs(yy-y))
+  
+  cdf.value <- sum(z[1:x.value,1:y.value])/sum(z)
+  return(cdf.value)
+}
+
+
+
+
 
 
 
@@ -441,7 +502,7 @@ Profit = function(o=OptPos(), S=o$S0){
 # #     #     if (is.null(type)) type='l'
 # #     #     if (is.null(lwd)) type=1
 # #     
-# #     plot(0,0, xlim=xlim, ylim=ylim, type='n', xlab=xlab, ylab=ylab, main=main,...); # draw blank canvas
+# #     plot(0,0, xlim=xlim, ylim=ylim, type='NSteps', xlab=xlab, ylab=ylab, main=main,...); # draw blank canvas
 # #     grid();
 # #     abline(0, 0, col='dark gray')
 # #     points(K, 0, col='black', pch=3)
@@ -486,7 +547,7 @@ Profit = function(o=OptPos(), S=o$S0){
 #     #     if (is.null(type)) type='l'
 #     #     if (is.null(lwd)) type=1
 #     
-#     plot(0,0, xlim=xlim, ylim=ylim, type='n', xlab=xlab, ylab=ylab, main=main,...); # draw blank canvas
+#     plot(0,0, xlim=xlim, ylim=ylim, type='NSteps', xlab=xlab, ylab=ylab, main=main,...); # draw blank canvas
 #     grid();
 #     abline(0, 0, col='dark gray')
 #     points(K, 0, col='black', pch=3)
@@ -505,10 +566,10 @@ Profit = function(o=OptPos(), S=o$S0){
 
 
 # plot.ts ####
-# BOPM.n = function(i) BOPM( OptPx(Opt('Am', 'P', 810, 0.5, 800), r=0.05, q=0.02, vol=0.2, n=i), IncBT=FALSE)$PxBT
-# plot.ts(sapply(2:100, BOPM.n))
+# BOPM.NSteps = function(i) BOPM( OptPx(Opt('Am', 'P', 810, 0.5, 800), r=0.05, q=0.02, vol=0.2, NSteps=i), IncBT=FALSE)$PxBT
+# plot.ts(sapply(2:100, BOPM.NSteps))
 # 
-# BT = BOPM( OptPx(Opt('Am', 'P', 810, 0.5, 800), r=0.05, q=0.02, vol=0.2, n=10))$BT
+# BT = BOPM( OptPx(Opt('Am', 'P', 810, 0.5, 800), r=0.05, q=0.02, vol=0.2, NSteps=10))$BT
 # 
 # lapply(1:10, function(i) BT[[i]][,1])
 # 
